@@ -14,9 +14,9 @@ internalVars = get("internalVars", envir = .emuR_pkgEnv)
 #################################
 test_that("unaltered bundle (sqlTableRep) validates successfully", {
   # delete, copy and load
-  unlink(path2db, recursive = T)
-  file.copy(path2orig, path2testData, recursive = T)
-  ae = load_emuDB(path2db, inMemoryCache = internalVars$testingVars$inMemoryCache, verbose = F)
+  unlink(path2db, recursive = TRUE)
+  file.copy(path2orig, path2testData, recursive = TRUE)
+  ae = load_emuDB(path2db, inMemoryCache = internalVars$testingVars$inMemoryCache, verbose = FALSE)
   
   res = validate_bundleDBI(ae, session = "0000", bundle = "msajc003")
   expect_equal(res$type, 'SUCCESS')
